class Foo {
  accessor prop = 1;
  static accessor prop2 = 1;
  accessor #prop3 = 1;
  accessor [prop4] = 1;
  accessor prop5 = 1;
  accessor #p;
  accessor a;
  accessor aa;
  accessor g;
}
